==> familia_0.1.tar.gz: familia/src/file/family.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FAMILY_H
#define _FAMILY_H

#include <glibmm/ustring.h>
#include <vector>

using namespace std;

namespace file {

class Family {
public:
  typedef Family _Myt;
  typedef Glib::ustring _String;
protected:
  int _id;
  //  <Children Order="ind00118, ind00119, ind00120, ind00121"/>
  vector<int> _children;
public:
  Family();
  Family(int identifier);

  const int getId();
  const vector<int> getChildren();

  _Myt& addChild(int identifier);
};

};

#endif

==> familia_0.1.2.tar.gz: familia/src/file/family.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FAMILY_H
#define _FAMILY_H

#include <glibmm/ustring.h>
#include <vector>

#include "unique.h"

using namespace std;

namespace file {

class Family : public Unique {
public:
  typedef Family _Myt;
  typedef Glib::ustring String;
protected:
  //  <Children Order="ind00118, ind00119, ind00120, ind00121"/>
  vector<int> _children;
public:
  Family();
  ~Family();

  const vector<int> getChildren();

  _Myt& addChild(int identifier);
};

};

#endif
